% BVAR: IRF differences regression analyses 
tic; clear; clc; close all;

%  add path of required Matlab functions
addpath('functions');

%  specify name of dataset
addpath('data');

%  specify name of output directory
addpath('output');

load('imprespdrawstoreSR.mat');  

set.dataFile = [pwd '\data\Data.csv'];

% series names
temptable = readtable(set.dataFile);

% series names
data.raw.nameSer  = temptable(1:end,1);

%  countries
data.raw.nameCtry = temptable.Properties.VariableNames;
data.raw.nameCtry = data.raw.nameCtry(2:5);

%  load raw data 
data.raw.y = csvread(set.dataFile,1,1);

[ horizon, N, junk, Ndraws ] = size(imprespdrawstore); 
 
% shock: MP shock
shockselect = [9];

% varselect: FR DE IT SP 
varselect = [ 1; ...
              3; ...
              5; ... 
              7 ];      
 
% names of variables
varlabels = [{'RGDP'}; {'HICP'}; {'M3'}; {'LOANS'}; {'R5Y'}];
          
% reordering DE FR IT SP (benchmark first) 
vorder = [ 2; 1; 3; 4 ]; 
var_mat = varselect(vorder,:); 
         

ctnames = char('DE','FR','IT','ES'); 

horselect = [10];  % selects IRF at horizons 4 and 8; impact period is one


if max(horselect)>horizon
 disp('Horizon exceeds IRF length');   
end

     
%% 
% start regression analysis


regselect=[1:12];    % selection of regressors

testout_store = NaN(size(regselect,2),2);
regcoeff = NaN(2,size(regselect,2),Ndraws);
resids = NaN(size(vorder,1)*size(horselect,2),size(regselect,2),1);
Rsq = NaN(size(regselect,2),Ndraws);

for ii=1:size(regselect,2)
   
    for jj=1:Ndraws
       
        ymat=NaN(size(vorder,1)*size(horselect,2),1);
        xmat =[ones(size(vorder,1)*size(horselect,2),1) NaN(size(vorder,1)*size(horselect,2),1)];
        
        for kk=1:size(vorder,1)
           
            ymat((kk-1)*size(horselect,2)+1:kk*size(horselect,2)) = squeeze(imprespdrawstore(horselect,varselect(vorder(kk)),shockselect,jj));
            
            for iii=1:size(horselect,2)
              xmat((kk-1)*size(horselect,2)+iii,2) = data.raw.y(ii,kk);
            end
            
            
        end
        
        xx = xmat'*xmat;
        xy = xmat'*ymat;
        regcoeff(:,ii,jj) = xx\xy; 
        residvec = ymat - xmat*squeeze(regcoeff(:,ii,jj));
        resids(:,ii,jj) = residvec;
        ressq = residvec'*residvec;
        ysq = var(ymat)*(size(ymat,1)-1);
        Rsq(ii,jj) = 1-ressq/ysq;
        
        
    end
        
    test = regcoeff(2,ii,:)<0;
    testout = sum(sum(test));
    
    disp(data.raw.nameSer(ii,1));
    disp(testout);
    
    testout_store(ii,1) = testout;
end

regcoeff_c1 = regcoeff;
resids_1 = resids;
%%
% compute median

medbeta = prctile(squeeze(regcoeff_c1(end,:,:)),50,2);
medRsq = NaN(size(regselect,2),1);

[junk, idx] = sort(squeeze(regcoeff_c1(end,:,:)),2);

if mod(Ndraws,2)==0
    for ii=1:size(regselect,2)
        medRsq(ii,1) = 0.5*(Rsq(ii,idx(ii,Ndraws/2))+Rsq(ii,idx(ii,Ndraws/2+1)));
    end        
else
    for ii=1:size(regselect,2)        
        medRsq(ii,1) = Rsq(ii,idx(ii,(Ndraws+1)/2));
    end
end

% normal kernel smoother for Rsquared

% compute weights
betadev = (squeeze(regcoeff_c1(end,:,:)) - kron(medbeta,ones(1,Ndraws)))./std(squeeze(regcoeff_c1(end,:,:)),[],2);
weights = normpdf(betadev,0,1);
weights = weights./sum(weights,2);

medRsq_kernel = diag(Rsq * weights');

stdbeta = std(squeeze(regcoeff_c1(end,:,:)),[],2);
probrat_beta = testout_store(:,1)/Ndraws;
invprobrat_beta = ones(size(probrat_beta))-probrat_beta;

% save output

results.varnames = data.raw.nameSer;
results.cnames = data.raw.nameCtry;
results.medbeta = medbeta;
results.probrat = probrat_beta;
results.invprobrat = invprobrat_beta;
results.Rsquared = medRsq_kernel;

save([pwd '\output\results_reg.mat'],'results');


