% BVAR_default_options
%
% Sets default options for BVAR following Giannone, Lenza and Primiceri
% (2014), Prior selection for vector autoregressions, Review of Economics
% and Statistics (forthcoming).

%% This part sets some program specifications to default values if not chosen
%  by user.
if ~exist('pos','var')
    pos=[];
end

if ~exist('mcmc','var')
    mcmc=0; 
elseif mcmc==1 && ~exist('MCMCdraw','var')
    MCMCdraw=1;
elseif mcmc==0 
    MCMCdraw=0;
end

if ~exist('step','var')
    step=1;
end

if ~exist('reps','var')
    reps=20000;
end

if ~exist('burn','var')
    burn=round(reps/2);
end

%% This part sets the choices for the estimation of the hyperparameters.
%  Default is estimation of all hyperparameters excluding alpha.
%
if ~exist('hyperpriors','var')
    hyperpriors=1;
end

if ~exist('hypfix','var')
    hypfix=0; 
end

if hypfix==1 && MCMCdraw==0;    % Fixed hyperparameters and no drawing for VAR 
    mcmc=0;                     % parameters does not imply any drawing at all.
    disp('hypfix=1 and MCMdraw=0 implies no drawing!');
    disp('mcmc set to zero.');
end

if ~exist('Vc','var')
    Vc=10e6;
end

if ~exist('MNpsi','var')
    mn.psi=1;
else
    mn.psi=MNpsi;
end

if ~exist('MNalpha','var')
    mn.alpha=0;
else
    mn.alpha=MNalpha;
end

if ~exist('MNlambda','var')
    mn.lambda=1;
else
    mn.lambda=MNlambda;
end
    
if ~exist('sur','var')
    sur=1;
end

if ~exist('noc','var')
    noc=1;
end

%% This sets the values for the hyperparameters in case they are not estimated.
%  Diagonal elements of Psi will be set equal to the variances from AR regressions.

% If you want to run a standard, fixed hyperparameters VAR, change the
% following settings to your prior.

defaultpar.alpha=2;
defaultpar.lambda=0.1;
defaultpar.miu=1;                     % noc prior
defaultpar.theta=1;                     % sur prior