% Plots of prior and posterior distributions of hyperparameters
% 
% Required inputs:
% Files saved by BVAR_revised.m
%
% \output\estimates.mat
%
% NOTE: code is written for optimal selection of lambda, theta, miu and
% PSI. If some of these variables have been fixed in estimation part of the
% commands must be commented out.
%
tic; clear all; clc; close all;

%  add path of required Matlab functions
addpath('functions');

%  specify name of dataset
addpath('data');

%  specify name of estimation/forecast output directory
addpath('output');

%% load output from estimation procedure 
%
load('estimates.mat');

% pick only hyperparameters that are included in 500 save steps
select = 500:500:size(res.mcmc.savHyp,1);
select = select(end-4999:end);

lambda=res.mcmc.savHyp(select,1);
theta=res.mcmc.savHyp(select,end-1);
miu=res.mcmc.savHyp(select,end);
%alpha=res.savHyp(select,end); % if alpha is estimated and not fixed shift the "end-i" above to
%"end-i-1"


%% compute parameters of prior distributions
%

mode.lambda=.2;     % hyperpriors modes
mode.miu=1;
mode.theta=1;
        
sd.lambda=.4;       % hyperpriors std
sd.miu=1;
sd.theta=1;
        
  
priorcoef.lambda=GammaCoef(mode.lambda,sd.lambda,0);  % coefficients of hyperpriors
priorcoef.miu=GammaCoef(mode.miu,sd.miu,0);
priorcoef.theta=GammaCoef(mode.theta,sd.theta,0);    


%% graph simulated distributions of hyperparameters

figure(1);

subplot(2,2,1);

[num,x]=hist(lambda,0:0.001:2);
priorpdflambda=pdf('Gamma',x,priorcoef.lambda.k,priorcoef.lambda.theta);
[density,z]  = ksdensity(lambda(1:end),x);

plot(x,density,'LineWidth', 2);
hold on;
plot(x,priorpdflambda,'-r','LineWidth', 2);
axis tight;
title('\lambda');

subplot(2,2,2);
[num,x]=hist(theta,0:0.001:2);
priorpdftheta=pdf('Gamma',x,priorcoef.theta.k,priorcoef.theta.theta);
[density,z]  = ksdensity(theta(1:end),x);

plot(x,density,'LineWidth', 2);
hold on;
plot(x,priorpdftheta,'-r','LineWidth', 2);
title('\theta');

subplot(2,2,3);
[num,x]=hist(miu,0:0.001:2.5);
priorpdfmiu=pdf('Gamma',x,priorcoef.miu.k,priorcoef.miu.theta);
[density,z]  = ksdensity(miu(1:end),x);

plot(x,density,'LineWidth', 2);
hold on;
plot(x,priorpdfmiu,'-r','LineWidth', 2);
axis tight;
title('\mu');

druck = figure(1);
outputdateiFigRes = strcat('output\posterior_hyper.eps');
print(druck,'-depsc', outputdateiFigRes);

outputdateiFigRes = strcat('output\posterior_hyper.png');
print(druck,'-dpng', outputdateiFigRes);




    




