% Computes and graphs sacrifice ratio from impulse responses
% 
% Note: computation assumes that relevant variables are in levels
%
%
% \output\imprespdrawstoreSR.mat:     impulse responses from model
%
tic; clear all; clc; close all;

%  add path of required Matlab functions
addpath('functions');

%  specify name of dataset
addpath('data');

%  specify name of estimation/forecast output directory
addpath('output');

% load variable names
load('varnames.mat');

% load impulse responses 
load('imprespdrawstoreSR');

[nhorizon,N,Nshocks,Ndraws]=size(imprespdrawstore);
%% specify horizons

shor=[4; 8; 12; 20];              % column vector indicating horizon(s) at which to compute sacrifice ratios
                        
shockselect=9;          % selects shock for which to perform the computation

select_y=[1; 3; 5; 7];  % column vector indicating positions of Y
select_p=[2; 4; 6; 8];  % column vector indicating positions of P

ctnames = char('FR','DE','IT','ES');    % country names
stylcol=['b';'k';'g';'r'];              % color codes
stylmar=[' ';'x';'o';'d'];              % use ' ' for no markers
symbolstep=50;
range=[-5:0.01:5];
steps=[1:symbolstep:size(range,2)];
markerlines=[0 1 1 1];  % denotes for which lines will plot markers

if max(shor)>nhorizon-1
    disp('Horizon exeeds length of impulse responses!');
    return;
end

if size(select_y)~=size(select_p)
    disp('Size of selection vectors does not match.');
    return;
end;

%% computes sacrifice ratios

iFigure=1;

for j=1:size(shor,1)
    
    tempy=squeeze(imprespdrawstore(:,select_y,shockselect,:));
    tempp=squeeze(imprespdrawstore(:,select_p,shockselect,:));
    
    meany=mean(tempy(1:shor(j)+1,:,:),1);     % 1st element is impact effect of shock
    sratio=meany./tempp(shor(j)+1,:,:);       % average output loss over price level reduction
           
    [num,x]=hist(sratio(1,1,:),range);
    
    for k=1:size(meany,2)
        
        [density,z]  = ksdensity(squeeze(sratio(1,k,:)),x);
        
        figure(iFigure);
        hc(k)=plot(z,density,stylcol(k),'LineWidth', 2);
        if markerlines(k)==1
           density2=NaN(size(density));
           density2(steps)=density(steps);
           hd(k)=plot(z,density2,strcat(stylcol(k),stylmar(k)),'LineWidth', 2);                 
           hc(k)=hd(k);
        end
        
        hold on;
        
        
    end
    hold off;
    
    legend(hc,ctnames,'Location','NorthEast');
    
    ha = axes('Position',[0 0 1 1],'Xlim',[0 1],'Ylim',[0 1], ...
        'Box','off','Visible','off','Units','normalized', 'clipping' , 'off');       
           
    text(0.5, 1,num2str(shor(j)),'HorizontalAlignment', ...
    'center','VerticalAlignment', 'top');
    
    druck = figure(iFigure);
    outputdateiFigRes = strcat('output\SRatio_',num2str(j),'.eps');
    print(druck,'-depsc', outputdateiFigRes);
    
    outputdateiFigRes = strcat('output\SRatio_',num2str(j),'.png');
    print(druck,'-dpng', outputdateiFigRes);
    
    iFigure=iFigure+1;

end


     