% Analysis of heterogeneity in impulse responses in Bayesian VAR model
%
% Required inputs:
%
% \output\imprespdrawstoreSR.mat
%
% \output\varnames.mat
%

clear all; clc; close all;

%  add path of required Matlab functions
addpath('functions');

%  specify name of output directory
addpath('output');

% load variable names
load('varnames.mat');

% load impulse responses 
load('imprespdrawstoreSR');

[nhorizon,N,Nshocks,Ndraws]=size(imprespdrawstore);
%% Setting specification parameters
%  
%  These must be consistent with those set for the estimation.

shockselect=9;      % which shock is to b used from impresdrawstore
shockvar=9;         % where is the variable included in the VAR

nni=3;              % #countries-1
nnjvec = 2;                             % index of variable of interest  
hzsp = [(0:24)'];
hzsp_select=[(1:24)'];

varname=[{'RGDP'} {'HICP'} {'M3'} {'LOANS'} {'R5Y'} ];                         % variable name

styl1=['-';'-';'-';':';':';':'];  
styl2=['x';'o';'d';'x';'o';'d']; 
collin=['k';'b';'r';'m';'g';'c'];

% enter variable groupings

% varselect: FR DE IT SP 
varselect = [ 1 2 10 11 12; ...
              3 4 13 14 15; ...
              5 6 16 17 18; ... 
              7 8 19 20 21];     
          
% reordering DE FR IT SP (benchmark first) 
vorder = [ 2; 1; 3; 4 ]; 
var_mat = varselect(vorder,:);           

ctnr = [ 1 1 1 2 2 3; ... 
         2 3 4 3 4 4 ]; 
ctnames = char('DE','FR','IT','ES'); 
cccn3 = '-'; 

nnj=size(ctnr,2);
a10=hzsp(end)+1;
 
% set up line entity

%% Kolmogorov-Smirnov test
% KS test variant
%
KStype='unequal'; % choose 'smaller', 'larger', default is 'unequal'

figure(1);

for ii=1:size(varselect,2)
    KSoutput=NaN(size(hzsp,1),3*nnj+1);
    KSoutput(:,1)=hzsp;
    col_header=cell(1,2*nnj);

    % distance measures for graph
    dplot=NaN(size(hzsp,1),nnj);
    legstring=cell(1,nnj);


    %% Test Loop
    for jj=1:nnj
       
        % response country 1    
        cc1n = ctnr(1,jj); 
        cc1 = var_mat(cc1n,ii);        
        irf1 = squeeze(imprespdrawstore(:,cc1,shockvar,:));  
        cccn1 = ctnames(cc1n,1:2);  

        % response country 2 
        cc2n = ctnr(2,jj); 
        cc2 = var_mat(cc2n,ii);        
        irf2 = squeeze(imprespdrawstore(:,cc2,shockvar,:));  
        cccn2 = ctnames(cc2n,1:2); 
        ccnn12 = strcat(cccn1,cccn3,cccn2); 

        for kk=1:size(hzsp,1)          
         [KSoutput(kk,3*jj-1), KSoutput(kk,3*jj), KSoutput(kk,3*jj+1)]=kstest2(irf1(hzsp(kk)+1,:),irf2(hzsp(kk)+1,:),'Tail',KStype);  
        end

        col_header{1,3*jj-2}=ccnn12;
        legstring(1,jj)={ccnn12};
        dplot(:,jj)=KSoutput(:,3*jj+1);

    end
    
    if ii==1
        figure(2);
        temp=ones(nnj,2);
        p1 = plot(temp(1,:),[1 2],'k-x',temp(2,:),[1 2],'b-o',temp(3,:),[1 2],'r-d',... 
            temp(4,:),[1 2],'m:x',temp(5,:),[1 2],'g:o',temp(6,:),[1 2],'c:d','LineWidth',2);
        l1 = legend(legstring);
        
    end

    figure(1);       
   
    s1 = subplot(3,2,ii);
     
    for jj=1:nnj
     plot(hzsp,dplot(:,jj),strcat(collin(jj),styl1(jj,:)),'LineWidth',2);
     hold on; 
     plot(hzsp(hzsp_select),dplot(hzsp_select,jj),strcat(collin(jj),styl2(jj,:)),'LineWidth',2);
    end

    hold off;
    ylim([0 0.5]);
    title(varname(1,ii)); 
    
    % this needs to be adjusted, first = lower left plot, second = upper
    % right
      if ii==5
          s1pos=get(s1,'Position');
      elseif ii==2
          s2pos=get(s1,'Position');
      end
            
     if ii==size(varselect,2)
         
         % position of new axis
         axpos = [s1pos(1), s1pos(2), s2pos(1)+s2pos(3)-s1pos(1), s2pos(2)+s2pos(4)-s1pos(2)];
 
         % create axis and hide it
         ax = axes('Position', axpos, 'Visible', 'off');
 
         % create legend
         legend(ax, p1, legstring, 'Visible', 'on', 'Location', 'SouthOutside', 'Orientation', 'Horizontal');
         
         % shift into position
         set(ax, 'Position', axpos);
     end
    
    



%% save results as Excel file
% first column: horizon, second column: reject=1, third column: pval

disp('Kolmogorov-Smirnov test - saved as Excel file KStest_xxx.xlsx');
Sheet=char(varname(1,ii));
xlswrite(strcat('output\KStest_',KStype,'.xlsx'),KSoutput,Sheet,'A2');
xlswrite(strcat('output\KStest_',KStype,'.xlsx'),col_header,Sheet,'B1');

end

druck = figure(1);
outputdateiFigRes = strcat('output\KSDist_',KStype,'.eps');
print(druck,'-depsc', outputdateiFigRes); 

druck = figure(1);
outputdateiFigRes = strcat('output\KSDist_',KStype,'.png');
print(druck,'-dpng', outputdateiFigRes); 