% Analysis of heterogeneity in impulse responses in Bayesian VAR model
%
% Required inputs:
%
% \output\imprespdrawstoreSR.mat
%
% \output\varnames.mat
%

clear all; clc; close all;

%  add path of required Matlab functions
addpath('functions');

%  specify name of output directory
addpath('output');

% load variable names
load('varnames.mat');

% load impulse responses 
load('imprespdrawstoreSR');

[nhorizon,N,Nshocks,Ndraws]=size(imprespdrawstore);
%% Setting specification parameters
%  
%  These must be consistent with those set for the estimation.

shockselect=9;      % which shock is to b used from impresdrawstore
shockvar=9;         % where is the variable included in the VAR

nni=3;              % #countries-1
                           
hzsp = [0; 1; 2; 4; 8; 12; 16; 20; 24];    % horizons

varname=[{'RGDP'} {'HICP'} {'M3'} {'LOANS'} {'R5Y'}];                         % variable names

% enter variable groupings

% varselect: FR DE IT SP 
varselect = [ 1 2 10 11 12; ...
              3 4 13 14 15; ...
              5 6 16 17 18; ... 
              7 8 19 20 21];         
          
% reordering DE FR IT SP (benchmark first) 
vorder = [ 2; 1; 3; 4 ]; 
var_mat = varselect(vorder,:);           

ctnr = [ 1 1 1 2 2 3; ... 
         2 3 4 3 4 4 ]; 
ctnames = char('DE','FR','IT','ES'); 
cccn3 = '-'; 

nnj=size(ctnr,2);
a10=hzsp(end)+1;

%% Parametric test for identity in median of IRF with unknown variance

for nnjvec = 1:size(varselect,2)

    MedTestOut=NaN(size(hzsp,1),3*nnj+1);
    MedTestOut(:,1)=hzsp;
    col_header=cell(1,3*nnj);

    for jj=1:nnj
        j=nnjvec;
        % response country 1    
        cc1n = ctnr(1,jj); 
        cc1 = var_mat(cc1n,j);        
        irf1 = squeeze(imprespdrawstore(:,cc1,shockvar,:));
        cccn1 = ctnames(cc1n,1:2);  

        % response country 2 
        cc2n = ctnr(2,jj); 
        cc2 = var_mat(cc2n,j);        
        irf2 = squeeze(imprespdrawstore(:,cc2,shockvar,:)); 
        cccn2 = ctnames(cc2n,1:2); 
        ccnn12 = strcat(cccn1,cccn3,cccn2); 

        %note: pvalue needs to be multiplied by 2 because of double sided test
        irf_diff=irf1-irf2;
        nall=Ndraws-sum(irf_diff==0,2);
        
        z1=sum(irf_diff<0,2);
        z2=nall-z1;
        zmax=max(z1,z2);

        pvalident=ones(nhorizon,1)-binocdf(zmax,nall,0.5);
        pvalabove=binocdf(z2,nall,0.5);
        pvalbelow=binocdf(z1,nall,0.5);

        MedTestOut(:,(jj-1)*3+2)=pvalident(hzsp+1,1);
        MedTestOut(:,jj*3)=pvalabove(hzsp+1,1);
        MedTestOut(:,jj*3+1)=pvalbelow(hzsp+1,1);

        col_header{1,3*jj-1}=ccnn12;

    end

    %% save results as Excel file
    % first column: horizon, second to fourth columsn: pvals for h0=identical, h0=above, h0=below

    disp('Median test - saved as Excel file Median.xlsx');
    Sheet=char(varname(1,nnjvec));
    xlswrite('output\Mediantest.xlsx',MedTestOut,Sheet,'A2');
    xlswrite('output\Mediantest.xlsx',col_header,Sheet,'A1');

end
