% testing convergence in Coefficients
function [ GCD, s_nc, IEF ] = BVAR_ConvTest(res,N,L,pplot)  

Nparam = N * L + 1;  

% for specific coefficients 
bbeta = res.mcmc.beta; 
  
diag_ief = NaN(Nparam,N); 
diag_ess = NaN(Nparam,N); 
diag_bbc = NaN(Nparam,N); 
for i = 1 : Nparam 
    for j = 1 : N 
        bbc1 = (squeeze(bbeta(i,j,:)))'; 
        diag_bbc1 = KDG0(bbc1); 
        diag_ief(i,j) = diag_bbc1(:,5); 
        diag_ess(i,j) = diag_bbc1(:,6); 
        diag_bbc(i,j) = diag_bbc1(:,7); 
    end 
end  
% Geweke statistics 
diag_bbc_v = diag_bbc(:); 
nc_diag_bbc = find( abs(diag_bbc_v) > 1.96 ); 
s_nc_diag_bbc = size(nc_diag_bbc,1); 
r_s_nc_diag_bbc = s_nc_diag_bbc / size(diag_bbc_v,1); 
% inefficiency factor 
diag_ief_v = diag_ief(:);  
  
% for specific covariances   
ssigma = res.mcmc.sigma; 
  
diag_sig_ief = NaN(N,N); 
diag_sig_ess = NaN(N,N); 
diag_sig_bbc = NaN(N,N); 
for i = 1 : N 
    for j = 1 : N 
        sig1 = (squeeze(ssigma(i,j,:)))'; 
        diag_sig1 = KDG0(sig1); 
        diag_sig_ief(i,j) = diag_sig1(:,5); 
        diag_sig_ess(i,j) = diag_sig1(:,6); 
        diag_sig_bbc(i,j) = diag_sig1(:,7); 
    end
end 
% Geweke statistics 
diag_sig_bbc_v = diag_sig_bbc(:);  
nc_diag_sig_bbc = find( abs(diag_sig_bbc_v) > 1.96 ); 
s_nc_diag_sig_bbc = size(nc_diag_sig_bbc,1);  
r_s_nc_diag_sig_bbc = s_nc_diag_sig_bbc / size(diag_sig_bbc_v,1); 
% inefficiency factor 
diag_sig_ief_v = diag_sig_ief(:);  
 

GCD = [ diag_bbc(:); diag_sig_bbc(:) ];   
s_nc = [ s_nc_diag_bbc size(diag_bbc_v,1) r_s_nc_diag_bbc; ... 
         s_nc_diag_sig_bbc size(diag_sig_bbc_v,1) r_s_nc_diag_sig_bbc ]; 
IEF = [ diag_ief_v; diag_sig_ief_v ]; 

twoline=ones(size(GCD))*1.96;

if pplot == 1 
    figure(1) 
    plot(GCD) 
    hold on;
    plot(twoline,'k');
    plot(-twoline,'k');
    hold off;
    title('Geweke statistics')
    
    druck = figure(1);
    outputdateiFigRes = strcat('output\Geweke_1.eps');
    print(druck,'-depsc', outputdateiFigRes);
    
    outputdateiFigRes = strcat('output\Geweke_1.png');
    print(druck,'-dpng', outputdateiFigRes);
  
    figure(2) 
    plot(IEF) 
    title('Inefficiency factors')
    
    druck = figure(2);
    outputdateiFigRes = strcat('output\Geweke_2.eps');
    print(druck,'-depsc', outputdateiFigRes);
    
      outputdateiFigRes = strcat('output\Geweke_2.png');
    print(druck,'-dpng', outputdateiFigRes);
    
end  
 
