function [S,ee]=BVARstability(beta,n,l,const)
% Checks for stability of VAR
%
%  Y = X*beta + e,  Y [T * n], X[k * n], k = l * n +1
%
% inputs:
%
% beta   (n*L+1)xn matrix with the coef from the VAR
% l      number of lags
% n      number of endog variables
% const  equal to one if constant is included in VAR;
%        constant is assumed to be ordered last in beta
%
% outputs:
%
% S      dummy var: if equal one->stability
% ee     maximum eigenvalue

if const==1
 beta=beta(1:end-1,:);
end

% write coefficients in companion form
FF=zeros(n*l,n*l);
FF(n+1:n*l,1:n*(l-1))=eye(n*(l-1),n*(l-1));

FF(1:n,1:n*l)=beta';
ee=max(abs(eig(FF)));
S=ee>1;


