function [seriesnew] = rescale_series(seriesold,option,trafoMat,dataFreq)
%rescale_series: rescales time series from 4xlog-levels to log-levels or
%levels
%
% inputs: 
% seriesold: matrix of time-series for rescaling; rows: time dimension;
%            columns: series; higher dimensions might contain different
%            draws etc.
%
% option:
% =1:        4*or 12* log-level back to log-level
% =2:        4* or 12* log-level back to level
% =3:        logs back to level
%
%
% trafoMat: Matrix of transformation codes used in setting up the VAR (see
%           BVAR_setup.m)
%
% output:
% 
% seriesnew: transformed series
%
% Last edited: 20.04.2015
%
%##########################################################################

nvars=size(seriesold,2);

seriesnew=seriesold;

if strcmp(dataFreq,'M')
    divFreq=12;
elseif strcmp(dataFreq,'A')
    divFreq=1;
else
    divFreq=4;
end
 

if option==1

    for i=1:nvars
        if trafoMat(2,i)==1 && trafoMat(3,i) == 0
            seriesnew(:,i,:)=seriesold(:,i,:)./divFreq;
        end
    end
    
elseif option==2
    
    for i=1:nvars
        if trafoMat(2,i)==1 && trafoMat(3,i) == 0
            seriesnew(:,i,:)=exp(seriesold(:,i,:)./divFreq);
        end
    end
    
elseif option==3
            
    for i=1:nvars
        if trafoMat(2,i)==1 && trafoMat(3,i) == 0
            seriesnew(:,i,:)=exp(seriesold(:,i,:));
        end
    end
   
    

end

